@@ -1,8 +1,8 @@
 """
-Module: 'esp32' on micropython-v1.18-esp32
+Module: 'esp32' on micropython-v1.19.1-esp32
 """
-# MCU: {'ver': 'v1.18', 'port': 'esp32', 'arch': 'xtensawin', 'sysname': 'esp32', 'release': '1.18.0', 'name': 'micropython', 'mpy': 10757, 'version': '1.18.0', 'machine': 'ESP32 module (spiram) with ESP32', 'build': '', 'nodename': 'esp32', 'platform': 'esp32', 'family': 'micropython'}
-# Stubber: 1.5.4
+# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'esp32', 'port': 'esp32', 'machine': 'ESP32 module (spiram) with ESP32', 'release': '1.19.1', 'nodename': 'esp32', 'name': 'micropython', 'family': 'micropython', 'sysname': 'esp32', 'version': '1.19.1'}
+# Stubber: 1.5.6
 from typing import Any
 
 HEAP_DATA = 4  # type: int
@@ -125,6 +125,10 @@ WAKEUP_ALL_LOW = False  # type: bool
 WAKEUP_ANY_HIGH = True  # type: bool
 
 
+def gpio_deep_sleep_hold(*args, **kwargs) -> Any:
+    ...
+
+
 def hall_sensor(*args, **kwargs) -> Any:
     ...
 
