@@ -1,8 +1,8 @@
 """
-Module: 'math' on micropython-v1.18-esp32
+Module: 'math' on micropython-v1.19.1-esp32
 """
-# MCU: {'ver': 'v1.18', 'port': 'esp32', 'arch': 'xtensawin', 'sysname': 'esp32', 'release': '1.18.0', 'name': 'micropython', 'mpy': 10757, 'version': '1.18.0', 'machine': 'ESP32 module (spiram) with ESP32', 'build': '', 'nodename': 'esp32', 'platform': 'esp32', 'family': 'micropython'}
-# Stubber: 1.5.4
+# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'esp32', 'port': 'esp32', 'machine': 'ESP32 module (spiram) with ESP32', 'release': '1.19.1', 'nodename': 'esp32', 'name': 'micropython', 'family': 'micropython', 'sysname': 'esp32', 'version': '1.19.1'}
+# Stubber: 1.5.6
 from typing import Any
 
 
@@ -81,6 +81,10 @@ def fabs(*args, **kwargs) -> Any:
     ...
 
 
+def factorial(*args, **kwargs) -> Any:
+    ...
+
+
 def floor(*args, **kwargs) -> Any:
     ...
 
@@ -97,6 +101,9 @@ def gamma(*args, **kwargs) -> Any:
     ...
 
 
+inf = inf  # type: float
+
+
 def isclose(*args, **kwargs) -> Any:
     ...
 
@@ -137,6 +144,7 @@ def modf(*args, **kwargs) -> Any:
     ...
 
 
+nan = nan  # type: float
 pi = 3.141593  # type: float
 
 
@@ -164,5 +172,8 @@ def tanh(*args, **kwargs) -> Any:
     ...
 
 
+tau = 6.283185  # type: float
+
+
 def trunc(*args, **kwargs) -> Any:
     ...
